@@ -59,24 +59,22 @@ g.shell.GGIR = function(mode=c(1,2),datadir=c(),outputdir=c(),studyname=c(),f0=1
     metadatadir = paste(outputdir,"/output_",outputfoldername,sep="")
   }
   # obtain default parameter values if not provided:
-  if (length(which(ls() == "selectdaysfile")) == 0)  selectdaysfile = c()
-  if (length(which(ls() == "diaryfile")) == 0)  diaryfile = c()
   
+  # GENERAL parameters:
   if (length(which(ls() == "overwrite")) == 0)  overwrite = FALSE
-  if (length(which(ls() == "strategy")) == 0)  strategy = 1
-  if (length(which(ls() == "maxdur")) == 0)  maxdur = 7
-  if (length(which(ls() == "do.cal")) == 0)  do.cal = TRUE
-  if (length(which(ls() == "hrs.del.start")) == 0)  hrs.del.start = 0
-  if (length(which(ls() == "hrs.del.end")) == 0)  hrs.del.end = 0
-  if (length(which(ls() == "loglocation")) == 0)  loglocation = c()
-  if (length(loglocation) == 1) {
-   if (loglocation == "") loglocation = c() #inserted because some users mistakingly use this
-  }
   if (length(which(ls() == "acc.metric")) == 0)  acc.metric = "ENMO"
   if (length(which(ls() == "storefolderstructure")) == 0)  storefolderstructure = FALSE
+  
+  if (length(which(ls() == "ignorenonwear")) == 0)  ignorenonwear = TRUE
+  if (length(which(ls() == "print.filename")) == 0)  print.filename = FALSE
+  # PART 1
+  if (length(which(ls() == "selectdaysfile")) == 0)  selectdaysfile = c()
+  if (length(which(ls() == "do.cal")) == 0)  do.cal = TRUE
+  if (length(which(ls() == "printsummary")) == 0)  printsummary = FALSE
   if (length(which(ls() == "windowsizes")) == 0)  windowsizes = c(5,900,3600)
   if (length(which(ls() == "minloadcrit")) == 0)  minloadcrit = 72
   if (length(which(ls() == "desiredtz")) == 0)  desiredtz = "Europe/London"
+  if (length(which(ls() == "configtz")) == 0)  configtz = c()
   if (length(which(ls() == "chunksize")) == 0)  chunksize = 1
   if (length(which(ls() == "do.enmo")) == 0)  do.enmo = TRUE
   if (length(which(ls() == "do.lfenmo")) == 0)  do.lfenmo = FALSE
@@ -96,9 +94,15 @@ g.shell.GGIR = function(mode=c(1,2),datadir=c(),outputdir=c(),studyname=c(),f0=1
   if (length(which(ls() == "do.dev_roll_med_acc_z")) == 0)  do.dev_roll_med_acc_z=FALSE
   if (length(which(ls() == "do.enmoa")) == 0)  do.enmoa = FALSE
   if (length(which(ls() == "dynrange")) == 0)  dynrange = c()
-  if (length(which(ls() == "printsummary")) == 0)  printsummary = FALSE
+  if (length(which(ls() == "idloc")) == 0) idloc = 1
+  if (length(which(ls() == "backup.cal.coef")) == 0)  backup.cal.coef = c()
+  
+  # PART 2
+  if (length(which(ls() == "strategy")) == 0)  strategy = 1
+  if (length(which(ls() == "maxdur")) == 0)  maxdur = 7
+  if (length(which(ls() == "hrs.del.start")) == 0)  hrs.del.start = 0
+  if (length(which(ls() == "hrs.del.end")) == 0)  hrs.del.end = 0
   if (length(which(ls() == "includedaycrit")) == 0)  includedaycrit = 16
-  if (length(which(ls() == "L5M5window")) == 0)  L5M5window = c(0,24)
   if (length(which(ls() == "M5L5res")) == 0)  M5L5res = 10
   if (length(which(ls() == "winhr")) == 0)  winhr = 5
   if (length(which(ls() == "qwindow")) == 0)  qwindow = c(0,24)
@@ -107,38 +111,42 @@ g.shell.GGIR = function(mode=c(1,2),datadir=c(),outputdir=c(),studyname=c(),f0=1
   if (length(which(ls() == "mvpathreshold")) == 0)  mvpathreshold = 100
   if (length(which(ls() == "boutcriter")) == 0)  boutcriter = 0.8
   if (length(which(ls() == "ndayswindow")) == 0)  ndayswindow = 7
-  if (length(which(ls() == "idloc")) == 0) idloc = 1
   if (length(which(ls() == "do.imp")) == 0) do.imp = TRUE
+  if (length(which(ls() == "IVIS_windowsize_minutes")) == 0)  IVIS_windowsize_minutes=60
+  if (length(which(ls() == "IVIS_epochsize_seconds")) == 0)  IVIS_epochsize_seconds=30
+  if (length(which(ls() == "mvpadur")) == 0)  mvpadur = c(1,5,10) # related to part 2 (functionality to anticipate part 5)
+  if (length(which(ls() == "epochvalues2csv")) == 0)  epochvalues2csv = FALSE
+  if (length(which(ls() == "window.summary.size")) == 0) window.summary.size = 10
+  if (length(which(ls() == "dayborder")) == 0)  dayborder = 0
+  if (length(which(ls() == "iglevels")) == 0)  iglevels = c()
+  
+  # PART 3
   if (length(which(ls() == "anglethreshold")) == 0)  anglethreshold = 5
   if (length(which(ls() == "timethreshold")) == 0)  timethreshold = 5
-  if (length(which(ls() == "ignorenonwear")) == 0)  ignorenonwear = FALSE
-  if (length(which(ls() == "idloc")) == 0)  idloc=1
+  if (length(which(ls() == "constrain2range")) == 0) constrain2range = TRUE
+  if (length(which(ls() == "do.part3.pdf")) == 0) do.part3.pdf = TRUE
+  
+  # PART 4
+  if (length(which(ls() == "loglocation")) == 0)  loglocation = c()
+  if (length(loglocation) == 1) {
+   if (loglocation == "") loglocation = c() #inserted because some users mistakingly use this
+  }
   if (length(which(ls() == "coldid")) == 0)  colid=1
   if (length(which(ls() == "coln1")) == 0)  coln1=1
   if (length(which(ls() == "nnights")) == 0)  nnights=7
   if (length(which(ls() == "outliers.only")) == 0)  outliers.only=FALSE
   if (length(which(ls() == "excludefirstlast")) == 0)  excludefirstlast=FALSE
-  if (length(which(ls() == "excludefirstlast.part5")) == 0)  excludefirstlast.part5=FALSE
   if (length(which(ls() == "criterror")) == 0)  criterror=3
-  if (length(which(ls() == "includenightcrit")) == 0)  includenightcrit=16
   if (length(which(ls() == "relyonsleeplog")) == 0)  relyonsleeplog=FALSE
   if (length(which(ls() == "sleeplogidnum")) == 0)  sleeplogidnum=TRUE
-  if (length(which(ls() == "def.noc.sleep")) == 0)  def.noc.sleep=c()
+  if (length(which(ls() == "def.noc.sleep")) == 0)  def.noc.sleep=1
   if (length(which(ls() == "do.visual")) == 0)  do.visual=FALSE
-  if (length(which(ls() == "viewingwindow")) == 0)  viewingwindow = 1
-  if (length(which(ls() == "dofirstpage")) == 0)  dofirstpage = TRUE
-  if (length(which(ls() == "visualreport")) == 0)  visualreport = FALSE
-  if (length(which(ls() == "print.filename")) == 0)  print.filename = FALSE
-  if (length(which(ls() == "backup.cal.coef")) == 0)  backup.cal.coef = c()
+  
+  # PART 5
+  if (length(which(ls() == "excludefirstlast.part5")) == 0)  excludefirstlast.part5=FALSE
+  if (length(which(ls() == "includenightcrit")) == 0)  includenightcrit=16
   if (length(which(ls() == "bout.metric")) == 0)  bout.metric = 1
   if (length(which(ls() == "closedbout")) == 0)  closedbout = FALSE
-  if (length(which(ls() == "IVIS_windowsize_minutes")) == 0)  IVIS_windowsize_minutes=60
-  if (length(which(ls() == "IVIS_epochsize_seconds")) == 0)  IVIS_epochsize_seconds=30
-  if (length(which(ls() == "acc.metric")) == 0) acc.metric = "ENMO"
-  if (length(which(ls() == "constrain2range")) == 0) constrain2range = TRUE
-  if (length(which(ls() == "do.part3.pdf")) == 0) do.part3.pdf = TRUE
-  
-  # # specific for part 5
   if (length(which(ls() == "boutcriter.in")) == 0)  boutcriter.in = 0.9
   if (length(which(ls() == "boutcriter.lig")) == 0)  boutcriter.lig = 0.8
   if (length(which(ls() == "boutcriter.mvpa")) == 0)  boutcriter.mvpa = 0.8
@@ -150,14 +158,13 @@ g.shell.GGIR = function(mode=c(1,2),datadir=c(),outputdir=c(),studyname=c(),f0=1
   if (length(which(ls() == "boutdur.in")) == 0)  boutdur.in = c(10,20,30)
   if (length(which(ls() == "boutdur.lig")) == 0)  boutdur.lig = c(1,5,10)
   if (length(which(ls() == "save_ms5rawlevels")) == 0) save_ms5rawlevels = FALSE
-  # part 2
-  if (length(which(ls() == "mvpadur")) == 0)  mvpadur = c(1,5,10) # related to part 2 (functionality to anticipate part 5)
-  if (length(which(ls() == "epochvalues2csv")) == 0)  epochvalues2csv = FALSE
-  # if (length(which(ls() == "bout.metric")) == 0) bout.metric = 1
-  if (length(which(ls() == "window.summary.size")) == 0) window.summary.size = 10
-  if (length(which(ls() == "dayborder")) == 0)  dayborder = 0
-  if (length(which(ls() == "iglevels")) == 0)  iglevels = c()
   
+  # VISUAL REPORT
+  if (length(which(ls() == "viewingwindow")) == 0)  viewingwindow = 1
+  if (length(which(ls() == "dofirstpage")) == 0)  dofirstpage = TRUE
+  if (length(which(ls() == "visualreport")) == 0)  visualreport = FALSE
+  
+
   cat("\n   Help sustain GGIR into the future \n")
   cat("   Check out: https://www.movementdata.nl/how-to-help-sustain-ggir \n")
   cat("   for more information. \n")
@@ -178,7 +185,7 @@ g.shell.GGIR = function(mode=c(1,2),datadir=c(),outputdir=c(),studyname=c(),f0=1
             do.cal = do.cal,print.filename=print.filename,
             overwrite=overwrite,backup.cal.coef=backup.cal.coef,
             selectdaysfile=selectdaysfile,dayborder=dayborder,
-            dynrange=dynrange)
+            dynrange=dynrange, configtz=configtz)
   }
   if (dopart2 == TRUE) {
     cat('\n')
@@ -188,7 +195,7 @@ g.shell.GGIR = function(mode=c(1,2),datadir=c(),outputdir=c(),studyname=c(),f0=1
     g.part2(datadir =datadir,metadatadir=metadatadir,f0=f0,f1=f1,strategy = strategy, 
             hrs.del.start = hrs.del.start,hrs.del.end = hrs.del.end,
             maxdur =  maxdur, includedaycrit = includedaycrit,
-            L5M5window = L5M5window, M5L5res = M5L5res, winhr = winhr,
+            M5L5res = M5L5res, winhr = winhr,
             qwindow=qwindow, qlevels = qlevels,
             ilevels = ilevels, mvpathreshold = mvpathreshold,
             boutcriter = boutcriter,ndayswindow=ndayswindow,idloc=idloc,do.imp=do.imp,
@@ -253,12 +260,6 @@ g.shell.GGIR = function(mode=c(1,2),datadir=c(),outputdir=c(),studyname=c(),f0=1
       stop()
     }
   }  
-  # if (visualreport==TRUE & length(do.report) == 0) { 
-  #   if (file.exists(paste(metadatadir,"/meta/ms4.out",sep=""))) {
-  #   } else {
-  #     do.report=c(2,4) #visual report is impossible without creating quantitative reports first
-  #   }
-  # }  
   if (length(which(do.report == 2)) > 0) {
     cat('\n')
     cat(paste0(rep('_',options()$width),collapse=''))
@@ -296,7 +297,6 @@ g.shell.GGIR = function(mode=c(1,2),datadir=c(),outputdir=c(),studyname=c(),f0=1
     cat(paste0(rep('_',options()$width),collapse=''))
     cat("\nGenerate visual reports\n")
     f1 = length(dir(paste(metadatadir,"/meta/ms4.out",sep="")))
-    # if (f1 == 0) f1 = length(dir(paste(metadatadir,"/meta/ms4.out",sep="")))
     g.plot5(metadatadir=metadatadir,dofirstpage=dofirstpage,
             viewingwindow=viewingwindow,f0=f0,f1=f1,overwrite=overwrite,desiredtz = desiredtz)
   }
